@@ -24,13 +24,12 @@ from snakeoil.mappings import ProtectedDict, ImmutableDict
 from snakeoil.log import suppress_logging
 from snakeoil.osutils import pjoin
 from snakeoil.process.spawn import spawn_get_output
-from snakeoil.sequences import (
-    split_negations, stable_unique, unstable_unique, predicate_split)
+from snakeoil.sequences import split_negations, stable_unique, predicate_split
 
 from pkgcore.binpkg import repository as binary_repo
 from pkgcore.cache.flat_hash import md5_cache
 from pkgcore.config import errors as config_errors
-from pkgcore.config.domain import Failure, MissingFile, domain as config_domain
+from pkgcore.config.domain import Failure, domain as config_domain
 from pkgcore.config.hint import ConfigHint
 from pkgcore.ebuild import const, repository as ebuild_repo
 from pkgcore.ebuild.atom import atom as _atom
@@ -131,7 +130,7 @@ def _read_config_file(path):
     except FileNotFoundError:
         pass
     except EnvironmentError as e:
-        raise Failure(f"failed reading {filename!r}: {e}") from e
+        raise Failure(f"failed reading {path!r}: {e}") from e
 
 
 def load_property(filename, *, read_func=_read_config_file,
@@ -627,23 +626,26 @@ class domain(config_domain):
     def add_repo(self, path, config, name=None, configure=True):
         """Add an external repo to the domain."""
         path = os.path.abspath(path)
-        if name is None:
-            # parse repo id from the given path
-            name = RepoConfig(path).repo_id
-            if name in self.source_repos_raw:
-                # fallback to using path for repo id in case of duplicate repos
-                name = path
-        if name in self.source_repos_raw:
-            raise ValueError(f'{name!r} repo already configured')
-        repo_config = RepoConfig(path, config_name=name)
+        # don't recreate existing repos
+        for repo in self.source_repos_raw:
+            if repo.location == path:
+                return repo
+        try:
+            # forcibly create repo_config object, otherwise cached version might be used
+            repo_config = RepoConfig(path, disable_inst_caching=True)
+        except OSError as e:
+            raise repo_errors.InvalidRepo(str(e))
         kwargs = {}
         if repo_config.cache_format is not None:
             # default to using md5 cache
             kwargs['cache'] = (md5_cache(path),)
         repo_obj = ebuild_repo.tree(config, repo_config, **kwargs)
-
-        # TODO: reset related jit attrs
         self.source_repos_raw += repo_obj
+
+        # reset repo-related jit attrs
+        for attr in (x for x in dir(self) if x.startswith('_jit_repo_')):
+            setattr(self, attr, None)
+
         if configure:
             return self._wrap_repo(repo_obj)
         return repo_obj
@@ -657,7 +659,7 @@ class domain(config_domain):
                 try:
                     repo = self.add_repo(path, config=config, configure=configure)
                     break
-                except repo_errors.InitializationError:
+                except repo_errors.InvalidRepo:
                     path = os.path.dirname(path)
         return repo
 
@@ -744,7 +746,7 @@ class domain(config_domain):
             return version[0].strip()
         raise ValueError('unknown kernel version')
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_source_repos_raw', uncached_val=None)
     def source_repos_raw(self):
         """Group of package repos without filtering."""
         repos = []
@@ -765,7 +767,7 @@ class domain(config_domain):
             repos.append(repo)
         return RepositoryGroup(repos)
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_installed_repos_raw', uncached_val=None)
     def installed_repos_raw(self):
         """Group of installed repos without filtering."""
         repos = [r.instantiate() for r in self.__vdb]
@@ -773,13 +775,13 @@ class domain(config_domain):
             repos.append(self.profile.provides_repo)
         return RepositoryGroup(repos)
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_repos_raw', uncached_val=None)
     def repos_raw(self):
         """Group of all repos without filtering."""
         return RepositoryGroup(
             chain(self.source_repos_raw, self.installed_repos_raw))
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_source_repos', uncached_val=None)
     def source_repos(self):
         """Group of configured, filtered package repos."""
         repos = []
@@ -790,7 +792,7 @@ class domain(config_domain):
                 logger.warning(f'skipping {repo.repo_id!r} repo: {e}')
         return RepositoryGroup(repos)
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_installed_repos', uncached_val=None)
     def installed_repos(self):
         """Group of configured, installed package repos."""
         repos = []
@@ -801,55 +803,55 @@ class domain(config_domain):
                 logger.warning(f'skipping {repo.repo_id!r} repo: {e}')
         return RepositoryGroup(repos)
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_unfiltered_repos', uncached_val=None)
     def unfiltered_repos(self):
         """Group of all configured repos without filtering."""
         repos = chain(self.source_repos, self.installed_repos)
         return RepositoryGroup(
             (r.raw_repo if r.raw_repo is not None else r) for r in repos)
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_repos', uncached_val=None)
     def repos(self):
         """Group of all repos."""
         return RepositoryGroup(
             chain(self.source_repos, self.installed_repos))
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_ebuild_repos', uncached_val=None)
     def ebuild_repos(self):
         """Group of all ebuild repos bound with configuration data."""
         return RepositoryGroup(
             x for x in self.source_repos
             if isinstance(x.raw_repo, ebuild_repo.ConfiguredTree))
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_ebuild_repos_unfiltered', uncached_val=None)
     def ebuild_repos_unfiltered(self):
         """Group of all ebuild repos without package filtering."""
         return RepositoryGroup(
             x for x in self.unfiltered_repos
             if isinstance(x, ebuild_repo.ConfiguredTree))
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_ebuild_repos_raw', uncached_val=None)
     def ebuild_repos_raw(self):
         """Group of all ebuild repos without filtering."""
         return RepositoryGroup(
             x for x in self.source_repos_raw
             if isinstance(x, ebuild_repo.UnconfiguredTree))
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_binary_repos', uncached_val=None)
     def binary_repos(self):
         """Group of all binary repos bound with configuration data."""
         return RepositoryGroup(
             x for x in self.source_repos
             if isinstance(x.raw_repo, binary_repo.ConfiguredTree))
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_binary_repos_unfiltered', uncached_val=None)
     def binary_repos_unfiltered(self):
         """Group of all binary repos without package filtering."""
         return RepositoryGroup(
             x for x in self.unfiltered_repos
             if isinstance(x, binary_repo.ConfiguredTree))
 
-    @klass.jit_attr_none
+    @klass.jit_attr_named('_jit_repo_binary_repos_raw', uncached_val=None)
     def binary_repos_raw(self):
         """Group of all binary repos without filtering."""
         return RepositoryGroup(
