@@ -9,7 +9,6 @@ import re
 import shlex
 import shutil
 import stat
-import sys
 
 from snakeoil.cli import arghparse
 from snakeoil.contexts import chdir
@@ -62,8 +61,7 @@ class UnknownArguments(IpcCommandError):
         super().__init__(f"unknown arguments: {', '.join(map(repr, args))}")
 
 
-class IpcArgumentParser(arghparse.OptionalsParser, arghparse.CsvActionsParser,
-                        arghparse.CopyableParser):
+class IpcArgumentParser(arghparse.ArgumentParser):
     """Raise IPC exception for argparse errors.
 
     Otherwise standard argparse prints the parser usage then outputs the error
@@ -71,8 +69,7 @@ class IpcArgumentParser(arghparse.OptionalsParser, arghparse.CsvActionsParser,
     """
 
     def __init__(self, *args, **kwargs):
-        kwargs.setdefault('add_help', False)
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, suppress=True, add_help=False, **kwargs)
 
     def error(self, msg):
         raise IpcCommandError(msg)
@@ -104,6 +101,7 @@ class IpcCommand:
         # read info from bash side
         nonfatal = self.read() == 'true'
         self.cwd = self.read()
+        self.phase = self.read()
         options = shlex.split(self.read())
         args = self.read().strip('\0')
         args = args.split('\0') if args else []
@@ -657,7 +655,7 @@ class Dosym(_Symlink):
     def run(self, args):
         target = args.target
         if (target.endswith(os.path.sep) or
-            (os.path.isdir(target) and not os.path.islink(target))):
+                (os.path.isdir(target) and not os.path.islink(target))):
             # bug 379899
             raise IpcCommandError(f'missing filename target: {target!r}')
         super().run(args)
@@ -927,7 +925,7 @@ class Eapply(IpcCommand):
             if arg == '--':
                 if files:
                     raise IpcCommandError('options must be specified before file arguments')
-                files = args[i + l:]
+                files = args[i + 1:]
                 break
             elif arg.startswith('-'):
                 if files:
@@ -990,7 +988,7 @@ class Eapply(IpcCommand):
                         raise IpcCommandError(msg, code=ret)
                 except OSError as e:
                     raise IpcCommandError(
-                    f'failed reading patch file: {patch!r}: {e.strerror}')
+                        f'failed reading patch file: {patch!r}: {e.strerror}')
 
 
 class Eapply_User(IpcCommand):
@@ -1012,12 +1010,12 @@ class Eapply_User(IpcCommand):
 
 class Unpack(IpcCommand):
 
-    arg_parser = IpcArgumentParser(add_help=False)
+    arg_parser = IpcArgumentParser()
     arg_parser.add_argument('targets', nargs='+')
 
     _file_mode = (
-        stat.S_IRUSR | stat.S_IRGRP | stat.S_IROTH \
-        | stat.S_IWUSR \
+        stat.S_IRUSR | stat.S_IRGRP | stat.S_IROTH
+        | stat.S_IWUSR
         & ~stat.S_IWGRP & ~stat.S_IWOTH
     )
     _dir_mode = _file_mode | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH
@@ -1057,7 +1055,7 @@ class Unpack(IpcCommand):
                         f"'./' in EAPI {self.eapi}")
 
             path = pjoin(srcdir, archive)
-            if not os.path.exists:
+            if not os.path.exists(path):
                 raise IpcCommandError(f'nonexistent file: {archive!r}')
             elif os.stat(path).st_size == 0:
                 raise IpcCommandError(f'empty file: {archive!r}')
@@ -1072,7 +1070,7 @@ class Unpack(IpcCommand):
 
     def run(self, args):
         spawn_kwargs = {}
-        if self.op.userpriv:
+        if self.op.userpriv and self.phase == 'unpack':
             spawn_kwargs['uid'] = os_data.portage_uid
             spawn_kwargs['gid'] = os_data.portage_gid
 
