@@ -105,7 +105,17 @@ class PortageConfig(DictMixin):
             dict: config settings
         """
         self._config = {}
-        location = location if location is not None else '/etc/portage'
+
+        if location is None:
+            location = '/etc/portage'
+            # fallback to stub config and profile on non-Gentoo systems
+            if not os.path.exists(location):
+                location = pjoin(const.DATA_PATH, 'stubconfig')
+                profile_override = pjoin(const.DATA_PATH, 'stubrepo/profiles/default')
+        elif location == pjoin(const.DATA_PATH, 'stubconfig'):
+            # override profile when using stub config
+            profile_override = pjoin(const.DATA_PATH, 'stubrepo/profiles/default')
+
         self.dir = pjoin(
             os.environ.get('PORTAGE_CONFIGROOT', kwargs.pop('configroot', '/')),
             location.lstrip('/'))
@@ -321,7 +331,12 @@ class PortageConfig(DictMixin):
                         f"repos.conf: parsing {fp!r}: "
                         f"{name!r} repo missing location setting, ignoring repo")
                     continue
-                repo_conf['location'] = os.path.abspath(location)
+                if os.path.isabs(location):
+                    repo_conf['location'] = location
+                else:
+                    # support relative paths based on where repos.conf is located
+                    repo_conf['location'] = os.path.abspath(
+                        pjoin(os.path.dirname(path), location))
 
                 # repo type defaults to ebuild for compat with portage
                 repo_type = repo_conf.get('repo-type', 'ebuild-v1')
