@@ -588,8 +588,8 @@ class Profiles(klass.ImmutableInstance):
                     os.path.join(profiles_base, path, 'deprecated'))
                 l.append(_KnownProfile(profiles_base, arch, path, status, deprecated))
         except FileNotFoundError:
-            logger.debug(
-                f"No profile descriptions found at {repo_id}::profiles/profiles.desc")
+            # no profiles exist
+            pass
         return frozenset(l)
 
     def __len__(self):
@@ -693,7 +693,10 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
             raise repo_errors.UnsupportedRepo(self)
 
         super().__init__(syncer)
-        self._parse_config()
+        try:
+            self._parse_config()
+        except OSError as e:
+            raise repo_errors.InitializationError(str(e))
 
     def _parse_config(self):
         """Load data from the repo's metadata/layout.conf file."""
@@ -759,7 +762,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
             # sort into favored order
             v = [f for f in self.supported_cache_formats if f in v]
             if not v:
-                logger.warning(f'unknown cache format: falling back to md5-dict format')
+                logger.warning('unknown cache format: falling back to md5-dict format')
                 v = ['md5-dict']
         sf(self, 'cache_format', list(v)[0])
 
@@ -977,7 +980,7 @@ class SquashfsRepoConfig(RepoConfig):
         if os.path.exists(self._sqfs):
             try:
                 self._mount_archive()
-            except PermissionError as e:
+            except PermissionError:
                 if platform.uname().release < '4.18':
                     raise repo_errors.InitializationError(
                         'fuse mounts in user namespaces require linux >= 4.18')
@@ -985,10 +988,11 @@ class SquashfsRepoConfig(RepoConfig):
         super().__init__(location, *args, **kwargs)
 
     def _pre_sync(self):
-        try:
-            self._umount_archive()
-        except repo_errors.InitializationError:
-            pass
+        if os.path.ismount(self.location):
+            try:
+                self._umount_archive()
+            except repo_errors.InitializationError:
+                pass
 
     def _post_sync(self):
         if os.path.exists(self._sqfs):
