@@ -96,11 +96,11 @@ class repo_operations(_repo_ops.operations):
             for pkg in pkgs:
                 pkgdir_fetchables.update({
                     fetchable.filename: fetchable for fetchable in
-                    iflatten_instance(pkg._get_attr['fetchables'](
-                        pkg, allow_missing_checksums=True,
+                    iflatten_instance(pkg.generate_fetchables(
+                        allow_missing_checksums=True,
                         skip_default_mirrors=(not mirrors)),
                         fetch.fetchable)
-                    })
+                })
 
             # fetchables targeted for (re-)manifest generation
             fetchables = {}
@@ -337,12 +337,6 @@ class UnconfiguredTree(prototype.tree):
         """
         super().__init__()
         self.base = self.location = location
-        try:
-            if not stat.S_ISDIR(os.stat(self.base).st_mode):
-                raise errors.InitializationError(f"base not a dir: {self.base}")
-        except OSError as e:
-            raise errors.InitializationError(f"lstat failed: {self.base}") from e
-
         if repo_config is None:
             repo_config = repo_objs.RepoConfig(location)
         self.config = repo_config
@@ -610,7 +604,7 @@ class UnconfiguredTree(prototype.tree):
         except pkg_errors.ParseChksumError as e:
             if e.missing and allow_missing:
                 return allow_missing, {}
-            raise
+            raise pkg_errors.MetadataException(pkg, 'manifest', str(e))
 
     def __repr__(self):
         return "<ebuild %s location=%r @%#8x>" % (
@@ -695,7 +689,7 @@ class ConfiguredTree(configured.tree):
             (x, domain_settings.get(x.upper(), chost))
             for x in ('cbuild', 'ctarget'))
         scope_update.update(
-            (x, domain_settings[x.upper()])
+            (x, domain_settings.get(x.upper(), ''))
             for x in ('cflags', 'cxxflags', 'ldflags'))
         scope_update['operations_callback'] = self._generate_pkg_operations
 
