@@ -5,7 +5,6 @@ __all__ = (
     "perl_rebuild", "perl_rebuild_main", "env_update", "env_update_main",
 )
 
-from collections import defaultdict
 from multiprocessing import cpu_count
 import os
 import re
@@ -13,14 +12,14 @@ import textwrap
 import time
 
 from snakeoil.cli import arghparse
-from snakeoil.compatibility import IGNORED_EXCEPTIONS
 from snakeoil.contexts import patch
 from snakeoil.fileutils import AtomicWriteFile
 from snakeoil.osutils import pjoin, listdir_dirs
 from snakeoil.sequences import iter_stable_unique
-from snakeoil.strings import pluralism
 
-from pkgcore.ebuild import processor, triggers
+from pkgcore import const
+from pkgcore.cache.flat_hash import md5_cache
+from pkgcore.ebuild import triggers, repository as ebuild_repo
 from pkgcore.ebuild.cpv import CPV
 from pkgcore.exceptions import PkgcoreUserException
 from pkgcore.fs import contents, livefs
@@ -28,7 +27,6 @@ from pkgcore.merge import triggers as merge_triggers
 from pkgcore.operations import observer as observer_mod, OperationError
 from pkgcore.package import mutated
 from pkgcore.package.errors import MetadataException
-from pkgcore.repository import multiplex
 from pkgcore.restrictions import packages
 from pkgcore.util import commandline
 from pkgcore.util.parserestrict import parse_match
@@ -278,6 +276,9 @@ regen_opts.add_argument(
 regen_opts.add_argument(
     "--force", action='store_true', default=False,
     help="force regeneration to occur regardless of staleness checks or repo settings")
+regen_opts.add_argument(
+    "--dir", dest='cache_dir',
+    help="use separate directory to store repository caches")
 regen_opts.add_argument(
     "--rsync", action='store_true', default=False,
     help="perform actions necessary for rsync repos (update metadata/timestamp.chk)")
@@ -294,6 +295,11 @@ def regen_main(options, out, err):
 
     observer = observer_mod.formatter_output(out)
     for repo in iter_stable_unique(options.repos):
+        if options.cache_dir is not None:
+            # recreate new repo object with cache dir override
+            cache = (md5_cache(pjoin(options.cache_dir.strip(os.sep), repo.repo_id)),)
+            repo = ebuild_repo.tree(
+                options.config, repo.config, cache=cache)
         if not repo.operations.supports("regen_cache"):
             out.write(f"repo {repo} doesn't support cache regeneration")
             continue
