@@ -19,14 +19,13 @@ from importlib import import_module
 import os
 import sys
 
-from snakeoil import formatters, modules
+from snakeoil import modules
 from snakeoil.cli import arghparse, tool
 from snakeoil.log import suppress_logging
 from snakeoil.osutils import pjoin, abspath, normpath
 from snakeoil.sequences import iflatten_instance, unstable_unique
 from snakeoil.strings import pluralism
 
-from pkgcore import const
 from pkgcore.config import basics, load_config
 from pkgcore.plugin import get_plugins
 from pkgcore.repository import errors as repo_errors
@@ -579,13 +578,15 @@ class ArgumentParser(arghparse.ArgumentParser):
                     project = __name__.split('.')[0]
 
                 # TODO: figure out a better method for plugin registry/loading
+                kwargs = {}
                 try:
                     plugins = import_module('.plugins', project)
-                    global_config = get_plugins('global_config', plugins)
-                    self.set_defaults(config=arghparse.DelayedValue(
-                        partial(store_config, global_config=global_config)))
+                    kwargs['global_config'] = get_plugins('global_config', plugins)
                 except ImportError:
+                    # project doesn't bundle plugins
                     pass
+                self.set_defaults(config=arghparse.DelayedValue(
+                    partial(store_config, **kwargs)))
 
             if domain:
                 _mk_domain(config_opts)
