@@ -5,6 +5,7 @@ import re
 import pytest
 from snakeoil.data_source import data_source
 from snakeoil.fileutils import touch
+from snakeoil.mappings import ImmutableDict
 
 from pkgcore.ebuild import repo_objs, atom
 from pkgcore.repository import errors as repo_errors
@@ -57,12 +58,16 @@ f"""<?xml version="1.0" encoding="UTF-8"?>
         names = ("foo@gmail.com", "monkeybone@gmail.com")
         mx = self.get_metadata_xml(maintainers=tuple((x,) for x in names))
         assert sorted(names) == sorted(map(str, mx.maintainers))
+        assert "foo@gmail.com" in mx.maintainers
+        assert "monkeybone@gmail.com" in mx.maintainers
 
     def test_maintainer_name_with_email(self):
         mx = self.get_metadata_xml(
             maintainers=(("funkymonkey@gmail.com", "funky monkey \N{SNOWMAN}"),))
         assert ("funky monkey \N{SNOWMAN} <funkymonkey@gmail.com>",) == \
             tuple(map(str, mx.maintainers))
+        assert "funkymonkey@gmail.com" in mx.maintainers
+        assert "funky monkey \N{SNOWMAN}" in mx.maintainers
         assert "funkymonkey@gmail.com" == mx.maintainers[0].email
         assert "funky monkey \N{SNOWMAN}" == mx.maintainers[0].name
         assert mx.maintainers[0].description is None
@@ -72,6 +77,8 @@ f"""<?xml version="1.0" encoding="UTF-8"?>
         mx = self.get_metadata_xml(
             maintainers=(("foo@bar.com", "foobar", "Foobar"),))
         assert ("foobar <foo@bar.com> (Foobar)",) == tuple(map(str, mx.maintainers))
+        assert "foo@bar.com" in mx.maintainers
+        assert "foobar" in mx.maintainers
         assert "foo@bar.com" == mx.maintainers[0].email
         assert "foobar" == mx.maintainers[0].name
         assert "Foobar" == mx.maintainers[0].description
@@ -82,6 +89,8 @@ f"""<?xml version="1.0" encoding="UTF-8"?>
             maintainers=(("foo@bar.com", "foobar"),),
             maint_type='person')
         assert ("foobar <foo@bar.com>",) == tuple(map(str, mx.maintainers))
+        assert "foo@bar.com" in mx.maintainers
+        assert "foobar" in mx.maintainers
         assert "foo@bar.com" == mx.maintainers[0].email
         assert "foobar" == mx.maintainers[0].name
         assert mx.maintainers[0].description is None
@@ -867,6 +876,43 @@ class TestRepoConfig:
         assert repo_config.known_arches == frozenset(['amd64', 'x86', 'foo-bar'])
         del repo_config
 
+    def test_arches_desc(self):
+        # nonexistent repo
+        repo_config = repo_objs.RepoConfig('nonexistent')
+        empty = {'stable': set(), 'transitional': set(), 'testing': set()}
+        assert repo_config.arches_desc == ImmutableDict(empty)
+        del repo_config
+
+        # empty file
+        os.mkdir(self.profiles_base)
+        arches_desc_path = os.path.join(self.profiles_base, 'arches.desc')
+        touch(arches_desc_path)
+        repo_config = repo_objs.RepoConfig(self.repo_path)
+        assert repo_config.arches_desc == ImmutableDict(empty)
+        del repo_config
+
+        # regular entries
+        with open(os.path.join(self.profiles_base, 'arch.list'), 'w') as f:
+            f.write(
+                """
+                amd64
+                alpha
+                foo
+                """)
+        with open(arches_desc_path, 'w') as f:
+            f.write(
+                """
+                # arches.desc file
+
+                amd64 stable
+                alpha testing
+                """)
+        repo_config = repo_objs.RepoConfig(self.repo_path)
+        assert repo_config.arches_desc['stable'] == {'amd64'}
+        assert repo_config.arches_desc['testing'] == {'alpha'}
+        assert repo_config.arches_desc['transitional'] == set()
+        del repo_config
+
     def test_use_desc(self):
         # nonexistent repo
         repo_config = repo_objs.RepoConfig('nonexistent')
